@@ -1,16 +1,18 @@
 package DTL::Fast::Expression::Operator::Binary::Plus;
-use strict; use utf8; use warnings FATAL => 'all';
+use strict; use utf8; use warnings FATAL => 'all'; 
 use parent 'DTL::Fast::Expression::Operator::Binary';
+use Carp qw(confess);
 
-$DTL::Fast::OPS_HANDLERS{'+'} = __PACKAGE__;
+$DTL::Fast::Expression::Operator::KNOWN{'+'} = __PACKAGE__;
 
 use Scalar::Util qw(looks_like_number);
+use DTL::Fast::Utils qw(has_method);
 
 sub dispatch
 {
     my( $self, $arg1, $arg2, $context) = @_;
     my ($arg1_type, $arg2_type) = (ref $arg1, ref $arg2);
-
+    
     if( looks_like_number($arg1) and looks_like_number($arg2))
     {
         return $arg1 + $arg2;
@@ -25,7 +27,7 @@ sub dispatch
         {
             return [@$arg1, %$arg2];
         }
-        elsif( UNIVERSAL::can($arg2, 'as_array'))
+        elsif( has_method($arg2, 'as_array'))
         {
             return [@$arg1, @{$arg2->as_array($context)}];
         }
@@ -44,16 +46,16 @@ sub dispatch
         {
             return {%$arg1, %$arg2};
         }
-        elsif( UNIVERSAL::can($arg2, 'as_hash'))
+        elsif( has_method($arg2, 'as_hash'))
         {
             return {%$arg1, %{$arg2->as_hash($context)}};
         }
         else
         {
-            die "Don't know how to add $arg2 ($arg2_type) to a HASH";
+            confess "Don't know how to add $arg2 ($arg2_type) to a HASH";
         }
     }
-    elsif( UNIVERSAL::can($arg1, 'plus'))
+    elsif( has_method($arg1, 'plus'))
     {
         return $arg1->plus($arg2, $context);
     }
@@ -63,4 +65,4 @@ sub dispatch
     }
 }
 
-1;
+1;
\ No newline at end of file
