@@ -1,6 +1,7 @@
 package DTL::Fast::Tag::Url;
 use strict; use utf8; use warnings FATAL => 'all'; 
 use parent 'DTL::Fast::Tag::Simple';
+use Carp qw(confess);
 
 $DTL::Fast::TAG_HANDLERS{'url'} = __PACKAGE__;
 
@@ -125,12 +126,9 @@ sub render_arguments
     {
         if( ref $self->{'arguments'} eq 'ARRAY' )
         {
-            $result = [];
-            
-            foreach my $argument (@{$self->{'arguments'}})
-            {
-                push @$result, $argument->render($context);
-            }
+            $result = [(
+                map{ $_->render($context) } @{$self->{'arguments'}}
+            )];
         }
         else    # MUST be a HASH
         {
